@@ -261,6 +261,13 @@ def django_sync_to_async_list(
 
     return result
 
+@sync_to_async
+def django_sync_to_async_get(
+        django_instance,
+        param_to_get,
+):
+    param = getattr(django_instance, param_to_get)
+    return param
 
 @sync_to_async
 def sync_to_async_get_django_field_data(django_field):
